<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>Для читання відомостей щодо диска слід пройти розпізнавання</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Запуск керування дисками потребує розпізнавання</translation>
		</message>
	</context>
</TS>